import os
from tkinter import Tk

from mygui import bgrid, egrid, lgrid

root = Tk()
root.minsize(300, 100)
lgrid(root, 'Label placed in grid 0,0', 0, 0, padx=20, pady=20)
lgrid(root, 'Label placed in grid 0,1', 0, 1)
egrid(root, 1, 0)
bgrid(root, "button", 2, 0, padx=20)
root.mainloop()



# LGRID , EGRID , BGRID

__version__ = "0.3.0"
__author__ = "Michael E Mulvey"
from tkinter import Button, Entry, Label, Tk


def lgrid(self, text, gridcol, gridrow, **kwargs):
    """Label Maker for quick labels in a GUI window.
    Example :
        lgrid(root,'text to enter',0,0)

    Where root is the instance of tkinter ,
    'Text to enter' is just that,
    0,0 is the column and row to place them"""
    lbl = Label(self, text=text, **kwargs)
    lbl.grid(column=gridcol, row=gridrow)


def egrid(self, col, row, **kwargs):
    """Entry Maker for a quick entry in a GUI window.
    Example:
    egrid(root,1,0)
    """
    e1 = Entry(self, **kwargs)
    e1.grid(column=col, row=row)


def bgrid(self, text, col, row, **kwargs):
    """Button Maker for quick entry in a grid"""
    btn1 = Button(self, text=text, command=quit, **kwargs)
    btn1.grid(column=col, row=row)



from tkinter import Tk

from mygui import bgrid, egrid, lgrid

root = Tk()
root.minsize(300, 100)
lgrid(root, "Label placed in grid 0,0", 0, 0)
lgrid(root, "Label placed in grid 0,1", 0, 1)
bgrid(root, "Buttonpress", 1, 1)
egrid(root, 1, 0)
root.mainloop()




import os

try:

    from mygui import lgrid
except:
    os.system('pip install mygui')
    from mygui import lgrid

from tkinter import Tk

root = Tk()


# Add Title from Filename

title = (os.path.basename(__file__)[0:-3])
root.title(title.title())

root.minsize(300, 100)

# Add Icon to window Titlebar (2024) rev
if os.name == 'nt':
    homepath = os.path.expanduser('~')
    tempFile = os.path.join(homepath, 'Caveman Software', 'Icon', 'icon.ico')

    if (os.path.exists(tempFile) == True):
        root.wm_iconbitmap(default=tempFile)

    else:
        import create_icon
        print('File Created')
        root.wm_iconbitmap(default=tempFile)

lgrid(root, 'Label placed in grid 5,5', 5, 5)
lgrid(root, 'Label placed in grid 6,6', 6, 6)

root.mainloop()



import os
from tkinter import Tk

from mygui import egrid, lgrid

root = Tk()


# Add Icon to window Titlebar (2024) rev
if os.name == 'nt':
    homepath = os.path.expanduser('~')
    tempFile = os.path.join(homepath, 'Caveman Software', 'Icon', 'icon.ico')

    if (os.path.exists(tempFile) == True):
        root.wm_iconbitmap(default=tempFile)

    else:
        import create_icon
        print('File Created')
        root.wm_iconbitmap(default=tempFile)


# Add Title from Filename

title = (os.path.basename(__file__)[0:-3])
root.title(title.title())

root.minsize(300, 100)
lgrid(root, 'Label placed in grid 0,0', 0, 0)
lgrid(root, 'Label placed in grid 0,1', 0, 1)
egrid(root, 1, 0)
root.mainloop()
